<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Networking.ServiceDiscovery.Dnssd

Windows Runtime (WinRT) APIs for for the `Windows.Networking.ServiceDiscovery.Dnssd` namespace.

This package provides the `winrt.windows.networking.servicediscovery.dnssd` module.
